<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\Esb\Controller\Adminhtml\ExternalInvoice;

use Magento\Framework\App\ResponseInterface;
use Magento\Framework\App\Filesystem\DirectoryList;

class PrintAction extends \Magento\Backend\App\Action
{
    /**
     * Authorization level of a basic admin session
     *
     * @see _isAllowed()
     */
    const ADMIN_RESOURCE = 'Magento_Sales::sales_invoice';

    /**
     * @var \Magento\Framework\App\Response\Http\FileFactory
     */
    protected $_fileFactory;

    /**
     * @var \Magento\Backend\Model\View\Result\ForwardFactory
     */
    protected $resultForwardFactory;

    protected $_orderRepository;

    protected $_scopeConfig;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\App\Response\Http\FileFactory $fileFactory
     * @param \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Magento\Sales\Api\OrderRepositoryInterface $orderRepository     
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\App\Response\Http\FileFactory $fileFactory,
        \Magento\Backend\Model\View\Result\ForwardFactory $resultForwardFactory,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Sales\Api\OrderRepositoryInterface $orderRepository
    ) {
        $this->_fileFactory = $fileFactory;
        $this->_orderRepository = $orderRepository;
        parent::__construct($context);
        $this->resultForwardFactory = $resultForwardFactory;
        $this->_scopeConfig = $scopeConfig;
    }

    /**
     * @return ResponseInterface|void
     */
    public function execute()
    {
        $orderId = $this->getRequest()->getParam('order_id');
        if ($orderId) {
            $order = $this->_orderRepository->get($orderId);
            if ($order) {
                $extensionAttributes=$order->getExtensionAttributes();
                $additionalData=current($extensionAttributes->getFbAdditionalData());
                $externalInvoices=$additionalData["external_invoices"];
                $invoice=current($externalInvoices);
                $documentFolder = $this->_scopeConfig->getValue(
                    'esb/print_documents/document_folder', 
                    \Magento\Store\Model\ScopeInterface::SCOPE_STORE
                );      
                return $this->_fileFactory->create(
                    $invoice["document_pdf"],
                    array(
                        'type'  => "filename", 
                        'value' => $documentFolder."/".$invoice["document_pdf"] 
                    ),
                    DirectoryList::VAR_DIR,
                    'application/pdf'
                );
            }
        } else {
            return $this->resultForwardFactory->create()->forward('noroute');
        }
    }
}